edges-analysis
==============

analysis
--------

High Level Interface
~~~~~~~~~~~~~~~~~~~~
.. autosummary::
    :toctree: _autosummary
    :template: module.rst

    edges_analysis.analysis.levels

Lower Level Methods
~~~~~~~~~~~~~~~~~~~
.. autosummary::
    :toctree: _autosummary
    :template: module.rst

    edges_analysis.analysis.beams
    edges_analysis.analysis.sky_models
    edges_analysis.analysis.filters
    edges_analysis.analysis.loss
    edges_analysis.analysis.s11
    edges_analysis.analysis.coordinates
    edges_analysis.analysis.tools
    edges_analysis.analysis.plots

simulation
----------
.. autosummary::
    :toctree: _autosummary
    :template: module.rst

    edges_analysis.simulation.data_models
    edges_analysis.simulation.plots

Package Config
--------------
.. autosummary::
    :toctree: _autosummary
    :template: module.rst

    edges_analysis.const
    edges_analysis.config
